export type Result<T, E extends Error> = Result.Success<T> | Result.Failure<E>;
export declare namespace Result {
    class Success<T> {
        readonly value: T;
        readonly state = "success";
        constructor(value: T);
        get error(): null;
        get valueOrError(): T;
        get(): T;
        map<T2>(mapper: (value: T) => T2): Result<T2, never>;
        mapError(): Result<T, never>;
    }
    class Failure<E extends Error> {
        readonly error: E;
        readonly state = "failure";
        constructor(error: E);
        get value(): null;
        get valueOrError(): E;
        get(): never;
        map(): Result<never, E>;
        mapError<E2 extends Error>(mapper: (value: E) => E2): Result<never, E2>;
    }
    function success<T>(value: T): Result<T, never>;
    function success(): Result<void, never>;
    function failure<E extends Error>(error: E): Result<never, E>;
    function isSuccess<T, E extends Error>(result: Result<T, E>): result is Result.Success<T>;
    function isFailure<T, E extends Error>(result: Result<T, E>): result is Result.Failure<E>;
}
